import { Component } from 'vue';
import { createRouter, createWebHashHistory, RouteRecordRaw } from 'vue-router';
import Layout from '@/layout/index.vue';

declare module 'vue-router' {
  interface RouteMeta {
    hidden?: boolean;
    title?: string;
    icon?: Component;
  }
}
export const routes: Array<RouteRecordRaw> = [
  { path: '/404', component: () => import('@/views/404.vue'), meta: { hidden: true } },
  { path: '/403', component: () => import('@/views/403.vue'), meta: { hidden: true } },
  {
    path: '',
    component: () => import('@/views/Home.vue'),
    meta: { title: '选择关卡' },
  },
  {
    path: '/role',
    component: () => import('@/views/Role.vue'),
    meta: { title: '选择角色' },
  },
  {
    path: '/report',
    component: () => import('@/views/report/Index.vue'),
    meta: { title: '实验报告' },
  },
  {
    path: '/product',
    redirect: '/product/index',
    component: Layout,
    children: [
      { path: 'bank', component: () => import('@/views/product/bank/List.vue'), meta: { title: '银行产品列表' } },
      { path: 'bank/:action', component: () => import('@/views/product/bank/CardList.vue'), meta: { title: '产品列表' } },
      { path: 'strategy', component: () => import('@/views/product/strategy/CardList.vue'), meta: { title: '产品列表' } },
      { path: 'insurance', component: () => import('@/views/product/insurance/List.vue'), meta: { title: '保险产品' } },
      { path: 'insurance/:action', component: () => import('@/views/product/insurance/CardList.vue'), meta: { title: '保险产品' } },
      { path: 'interestRate/:action', component: () => import('@/views/product/interestRate/CardList.vue'), meta: { title: '利率定价模型' } },
      { path: 'fund', component: () => import('@/views/product/fund/List.vue'), meta: { title: '基金产品' } },
      { path: 'fund/:action', component: () => import('@/views/product/fund/CardList.vue'), meta: { title: '基金产品' } },
      { path: 'afterLoan', component: () => import('@/views/product/afterLoan/CardList.vue'), meta: { title: '贷后管理' } },
    ],
  },
  {
    path: '/finance',
    // redirect: '/finance/index',
    component: Layout,
    meta: { title: '金融市场' },
    children: [
      { path: 'bank', component: () => import('@/views/finance/Bank.vue'), meta: { title: '银行市场' } },
      { path: 'insurance', component: () => import('@/views/finance/Insurance.vue'), meta: { title: '保险市场' } },
      { path: 'fund', component: () => import('@/views/finance/Fund.vue'), meta: { title: '基金市场' } },
      { path: 'publish', component: () => import('@/views/finance/Publish.vue'), meta: { title: '发布' } },
      { path: 'account', component: () => import('@/views/finance/Account.vue'), meta: { title: '我的账户' } },
      { path: 'order', component: () => import('@/views/finance/Order.vue'), meta: { title: '我的订单' } },
      { path: 'armory', component: () => import('@/views/finance/Armory.vue'), meta: { title: '英雄榜' } },
      { path: 'bankDetail', component: () => import('@/views/finance/BankDetail.vue'), meta: { title: '银行产品详情' } },
    ],
  },
  {
    path: '/config',
    redirect: '/config/index',
    component: Layout,
    children: [
      { path: 'index', component: () => import('@/views/config/param/Index.vue'), meta: { title: '参数配置' } },
      { path: 'level', component: () => import('@/views/config/level/Index.vue'), meta: { title: '关卡配置' } },
    ],
  },
  // 404 page must be placed at the end !!!
  {
    path: '/:pathMatch(.*)*',
    name: 'not-found',
    redirect: '/404',
    meta: { hidden: true },
  },
];
const router = createRouter({
  history: createWebHashHistory(),
  scrollBehavior: () => ({ top: 0 }),
  routes,
});

export default router;
