import { reactive, readonly } from 'vue';
import { RouteRecordRaw } from 'vue-router';
import { removeAccessToken, removeParam } from '@/utils/auth';
import Cookies from 'js-cookie';

export interface CurrentUser {
  username?: string;
  avatar?: string;
  permissions?: string[];
  loginDate?: Date;
  loginIp?: string;
}

const state = reactive<CurrentUser>({});

export const logout = (): void => {
  removeAccessToken();
  removeParam();
  window.location.href = decodeURIComponent(Cookies.get('sand-referrer'));
};

export const hasCurrentUser = (): boolean => state.username !== undefined;
export const hasPermission = (requiresPermission: string | undefined): boolean => !requiresPermission || (state.permissions?.includes(requiresPermission) ?? false);
export const perm = (requiresPermission: string | undefined): boolean => !hasPermission(requiresPermission);
export const isShowMenu = (route: RouteRecordRaw): boolean => !route.meta?.hidden && hasPermission(route.meta?.requiresPermission);
