import { h } from 'vue';
import axios from 'axios';
import { ElMessageBox, ElMessage } from 'element-plus';
import { getAuthHeaders } from '@/utils/auth';
import i18n from '@/i18n';
import { logout } from '@/store/useCurrentUser';

const service = axios.create({
  baseURL: import.meta.env.VITE_BASE_API,
  timeout: 10000,
});

service.interceptors.request.use(
  (config) => {
    config.headers = { ...config.headers, ...getAuthHeaders() };
    return config;
  },
  (error) => Promise.reject(error),
);

service.interceptors.response.use(
  (res) => {
    const { message, status } = res.data;
    if (status) {
      if (status === 200) {
        return res;
      }
      message === '无缓存' || ElMessage.error(message);
    } else {
      return res;
    }
  },
  (e) => {
    const {
      response: {
        data: { timestamp, message, path, error, exception, trace },
        status,
      },
    } = e;
    const {
      global: { t },
    } = i18n;
    if (status === 401) {
      ElMessageBox.confirm(t('confirmLogin'), { confirmButtonText: t('loginAgain'), type: 'warning' }).then(() => {
        // 未登录
        logout();
      });
    } else if (status === 403) {
      ElMessageBox({
        title: status,
        message: h('div', null, [h('p', { class: 'text-lg' }, t('error.forbidden')), h('p', { class: 'mt-2' }, message)]),
      });
    } else {
      ElMessage.error(message);
    }
    return Promise.reject(error);
  },
);

export default service;
